@@ -2,15 +2,16 @@
 JC cli module
 """
 
+import io
 import sys
 import os
 import textwrap
 import signal
 import shlex
 import subprocess
-import json
 from .lib import (__version__, parser_info, all_parser_info, parsers,
-                  _get_parser, _parser_is_streaming)
+                  _get_parser, _parser_is_streaming, standard_parser_mod_list,
+                  plugin_parser_mod_list, streaming_parser_mod_list)
 from . import utils
 from . import tracebackplus
 from .exceptions import LibraryNotInstalled, ParseError
@@ -21,13 +22,12 @@ try:
     from pygments import highlight
     from pygments.style import Style
     from pygments.token import (Name, Number, String, Keyword)
-    from pygments.lexers import JsonLexer
+    from pygments.lexers.data import JsonLexer, YamlLexer
     from pygments.formatters import Terminal256Formatter
     PYGMENTS_INSTALLED = True
 except Exception:
     PYGMENTS_INSTALLED = False
 
-
 JC_ERROR_EXIT = 100
 
 
@@ -37,7 +37,7 @@ class info():
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     website = 'https://github.com/kellyjonbrazil/jc'
-    copyright = f'© 2019-2022 Kelly Brazil'
+    copyright = '© 2019-2022 Kelly Brazil'
     license = 'MIT License'
 
 
@@ -84,16 +84,6 @@ if PYGMENTS_INSTALLED:
         }
 
 
-def asciify(string):
-    """
-    Return a string downgraded from Unicode to ASCII with some simple
-    conversions.
-    """
-    string = string.replace('©', '(c)')
-    string = ascii(string)
-    return string.replace(r'\n', '\n')
-
-
 def set_env_colors(env_colors=None):
     """
     Return a dictionary to be used in Pygments custom style class.
@@ -144,7 +134,7 @@ def set_env_colors(env_colors=None):
 
 def piped_output(force_color):
     """
-    Return False if stdout is a TTY. True if output is being piped to
+    Return False if `STDOUT` is a TTY. True if output is being piped to
     another program and foce_color is True. This allows forcing of ANSI
     color codes even when using pipes.
     """
@@ -190,6 +180,9 @@ def about_jc():
         'python_version': '.'.join((str(sys.version_info.major), str(sys.version_info.minor), str(sys.version_info.micro))),
         'python_path': sys.executable,
         'parser_count': len(all_parser_info()),
+        'standard_parser_count': len(standard_parser_mod_list()),
+        'streaming_parser_count': len(streaming_parser_mod_list()),
+        'plugin_parser_count': len(plugin_parser_mod_list()),
         'parsers': all_parser_info()
     }
 
@@ -220,6 +213,7 @@ def helptext():
             -r    raw JSON output
             -u    unbuffer output
             -v    version info
+            -y    YAML output
 
     Examples:
             Standard Syntax:
@@ -268,15 +262,57 @@ def versiontext():
     python path:  {sys.executable}
 
     {info.website}
-    {info.copyright}'''
+    {info.copyright}
+    '''
     return textwrap.dedent(versiontext_string)
 
 
-def json_out(data, pretty=False, env_colors=None, mono=False, piped_out=False):
+def yaml_out(data, pretty=False, env_colors=None, mono=False, piped_out=False, ascii_only=False):
+    """
+    Return a YAML formatted string. String may include color codes. If the
+    YAML library is not installed, output will fall back to JSON with a
+    warning message to STDERR"""
+    # make ruamel.yaml import optional
+    try:
+        from ruamel.yaml import YAML
+        YAML_INSTALLED = True
+    except Exception:
+        YAML_INSTALLED = False
+
+    if YAML_INSTALLED:
+        y_string_buf = io.BytesIO()
+        # monkey patch to disable plugins since we don't use them and in
+        # ruamel.yaml versions prior to 0.17.0 the use of __file__ in the
+        # plugin code is incompatible with the pyoxidizer packager
+        YAML.official_plug_ins = lambda a: []
+        yaml=YAML()
+        yaml.default_flow_style = False
+        yaml.explicit_start = True
+        yaml.allow_unicode = not ascii_only
+        yaml.encoding = 'utf-8'
+        yaml.dump(data, y_string_buf)
+        y_string = y_string_buf.getvalue().decode('utf-8')[:-1]
+
+        if not mono and not piped_out:
+            # set colors
+            class JcStyle(Style):
+                styles = set_env_colors(env_colors)
+
+            return str(highlight(y_string, YamlLexer(), Terminal256Formatter(style=JcStyle))[0:-1])
+
+        return y_string
+
+    utils.warning_message(['YAML Library not installed. Reverting to JSON output.'])
+    return json_out(data, pretty=pretty, env_colors=env_colors, mono=mono, piped_out=piped_out, ascii_only=ascii_only)
+
+
+def json_out(data, pretty=False, env_colors=None, mono=False, piped_out=False, ascii_only=False):
     """
     Return a JSON formatted string. String may include color codes or be
     pretty printed.
     """
+    import json
+
     separators = (',', ':')
     indent = None
 
@@ -284,28 +320,54 @@ def json_out(data, pretty=False, env_colors=None, mono=False, piped_out=False):
         separators = None
         indent = 2
 
+    j_string = json.dumps(data, indent=indent, separators=separators, ensure_ascii=ascii_only)
+
     if not mono and not piped_out:
         # set colors
         class JcStyle(Style):
             styles = set_env_colors(env_colors)
 
-        try:
-            return str(highlight(json.dumps(data,
-                                            indent=indent,
-                                            separators=separators,
-                                            ensure_ascii=False),
-                                 JsonLexer(), Terminal256Formatter(style=JcStyle))[0:-1])
-        except UnicodeEncodeError:
-            return str(highlight(json.dumps(data,
-                                            indent=indent,
-                                            separators=separators,
-                                            ensure_ascii=True),
-                                 JsonLexer(), Terminal256Formatter(style=JcStyle))[0:-1])
+        return str(highlight(j_string, JsonLexer(), Terminal256Formatter(style=JcStyle))[0:-1])
 
-    try:
-        return json.dumps(data, indent=indent, separators=separators, ensure_ascii=False)
-    except UnicodeEncodeError:
-        return json.dumps(data, indent=indent, separators=separators, ensure_ascii=True)
+    return j_string
+
+
+def safe_print_out(list_or_dict, pretty=None, env_colors=None, mono=None,
+                   piped_out=None, flush=None, yaml=None):
+    """Safely prints JSON or YAML output in both UTF-8 and ASCII systems"""
+    if yaml:
+        try:
+            print(yaml_out(list_or_dict,
+                           pretty=pretty,
+                           env_colors=env_colors,
+                           mono=mono,
+                           piped_out=piped_out),
+                  flush=flush)
+        except UnicodeEncodeError:
+            print(yaml_out(list_or_dict,
+                           pretty=pretty,
+                           env_colors=env_colors,
+                           mono=mono,
+                           piped_out=piped_out,
+                           ascii_only=True),
+                  flush=flush)
+
+    else:
+        try:
+            print(json_out(list_or_dict,
+                           pretty=pretty,
+                           env_colors=env_colors,
+                           mono=mono,
+                           piped_out=piped_out),
+                  flush=flush)
+        except UnicodeEncodeError:
+            print(json_out(list_or_dict,
+                           pretty=pretty,
+                           env_colors=env_colors,
+                           mono=mono,
+                           piped_out=piped_out,
+                           ascii_only=True),
+                  flush=flush)
 
 
 def magic_parser(args):
@@ -376,7 +438,8 @@ def run_user_command(command):
                             stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE,
                             close_fds=False,            # Allows inheriting file descriptors;
-                            universal_newlines=True)    # useful for process substitution
+                            universal_newlines=True,    #     useful for process substitution
+                            encoding='UTF-8')
     stdout, stderr = proc.communicate()
 
     return (
@@ -435,6 +498,7 @@ def main():
     raw = 'r' in options
     unbuffer = 'u' in options
     version_info = 'v' in options
+    yaml_out = 'y' in options
 
     if verbose_debug:
         tracebackplus.enable(context=11)
@@ -443,25 +507,20 @@ def main():
         mono = True
 
     if about:
-        print(json_out(about_jc(),
-              pretty=pretty,
-              env_colors=jc_colors,
-              mono=mono,
-              piped_out=piped_output(force_color)))
+        safe_print_out(about_jc(),
+                       pretty=pretty,
+                       env_colors=jc_colors,
+                       mono=mono,
+                       piped_out=piped_output(force_color),
+                       yaml=yaml_out)
         sys.exit(0)
 
     if help_me:
-        try:
-            print(help_doc(sys.argv))
-        except UnicodeEncodeError:
-            print(asciify(help_doc(sys.argv)))
+        utils._safe_print(help_doc(sys.argv))
         sys.exit(0)
 
     if version_info:
-        try:
-            print(versiontext())
-        except UnicodeEncodeError:
-            print(asciify(versiontext()))
+        utils._safe_print(versiontext())
         sys.exit(0)
 
     # if magic syntax used, try to run the command and error if it's not found, etc.
@@ -476,7 +535,7 @@ def main():
         try:
             magic_stdout, magic_stderr, magic_exit_code = run_user_command(run_command)
             if magic_stderr:
-                print(magic_stderr[:-1], file=sys.stderr)
+                utils._safe_print(magic_stderr[:-1], file=sys.stderr)
 
         except OSError as e:
             if debug:
@@ -540,12 +599,13 @@ def main():
                                   quiet=quiet,
                                   ignore_exceptions=ignore_exceptions)
             for line in result:
-                print(json_out(line,
+                safe_print_out(line,
                                pretty=pretty,
                                env_colors=jc_colors,
                                mono=mono,
-                               piped_out=piped_output(force_color)),
-                      flush=unbuffer)
+                               piped_out=piped_output(force_color),
+                               flush=unbuffer,
+                               yaml=yaml_out)
 
             sys.exit(combined_exit_code(magic_exit_code, 0))
 
@@ -555,12 +615,14 @@ def main():
             result = parser.parse(data,
                                   raw=raw,
                                   quiet=quiet)
-            print(json_out(result,
+
+            safe_print_out(result,
                            pretty=pretty,
                            env_colors=jc_colors,
                            mono=mono,
-                           piped_out=piped_output(force_color)),
-                  flush=unbuffer)
+                           piped_out=piped_output(force_color),
+                           flush=unbuffer,
+                           yaml=yaml_out)
 
         sys.exit(combined_exit_code(magic_exit_code, 0))
 
@@ -575,14 +637,6 @@ def main():
         ])
         sys.exit(combined_exit_code(magic_exit_code, JC_ERROR_EXIT))
 
-    except json.JSONDecodeError:
-        if debug:
-            raise
-
-        utils.error_message(['There was an issue generating the JSON output.',
-                             'For details use the -d or -dd option.'])
-        sys.exit(combined_exit_code(magic_exit_code, JC_ERROR_EXIT))
-
     except Exception:
         if debug:
             raise
