@@ -15,16 +15,11 @@ Usage (module):
     import jc
     result = jc.parse('lsusb', lsusb_command_output)
 
-    or
-
-    import jc.parsers.lsusb
-    result = jc.parsers.lsusb.parse(lsusb_command_output)
-
 Schema:
 
-    Note: <item> object keynames are assigned directly from the lsusb
-          output. If there are duplicate <item> names in a section, only the
-          last one is converted.
+> Note: <item> object keynames are assigned directly from the lsusb
+> output. If there are duplicate <item> names in a section, only the
+> last one is converted.
 
     [
       {
