@@ -13,29 +13,24 @@ Usage (module):
     import jc
     result = jc.parse('route', route_command_output)
 
-    or
-
-    import jc.parsers.route
-    result = jc.parsers.route.parse(route_command_output)
-
 Schema:
 
     [
       {
-        "destination":     string,
-        "gateway":         string,
-        "genmask":         string,
-        "flags":           string,
+        "destination":        string,
+        "gateway":            string,
+        "genmask":            string,
+        "flags":              string,
         "flags_pretty": [
-                           string
+                              string
         ]
-        "metric":          integer,
-        "ref":             integer,
-        "use":             integer,
-        "mss":             integer,
-        "window":          integer,
-        "irtt":            integer,
-        "iface":           string
+        "metric":             integer,
+        "ref":                integer,
+        "use":                integer,
+        "mss":                integer,
+        "window":             integer,
+        "irtt":               integer,
+        "iface":              string
       }
     ]
 
