@@ -22,11 +22,6 @@ Usage (module):
     import jc
     result = jc.parse('sfdisk', sfdisk_command_output)
 
-    or
-
-    import jc.parsers.sfdisk
-    result = jc.parsers.sfdisk.parse(sfdisk_command_output)
-
 Schema:
 
     [
