@@ -14,11 +14,6 @@ Usage (module):
     import jc
     result = jc.parse('systemctl_ls', systemctl_ls_command_output)
 
-    or
-
-    import jc.parsers.systemctl_ls
-    result = jc.parsers.systemctl_ls.parse(systemctl_ls_command_output)
-
 Schema:
 
     [
