@@ -21,11 +21,6 @@ Usage (module):
     import jc
     result = jc.parse('ufw_appinfo', ufw_appinfo_command_output)
 
-    or
-
-    import jc.parsers.ufw_appinfo
-    result = jc.parsers.ufw_appinfo.parse(ufw_appinfo_command_output)
-
 Schema:
 
     [
