@@ -1,17 +1,28 @@
 """jc - JSON Convert universal parsers"""
+from typing import Iterable, List, Dict
 
 
-import string
-from typing import List, Dict
-
-
-def simple_table_parse(data: List[str]) -> List[Dict]:
+def simple_table_parse(data: Iterable[str]) -> List[Dict]:
     """
-    Parse simple tables. The last column may contain data with spaces.
+    Parse simple tables. There should be no blank cells. The last column
+    may contain data with spaces.
+
+    Example Table:
+
+        col_1     col_2     col_3     col_4     col_5
+        apple     orange    pear      banana    my favorite fruits
+        carrot    squash    celery    spinach   my favorite veggies
+        chicken   beef      pork      eggs      my favorite proteins
+
+        [{'col_1': 'apple', 'col_2': 'orange', 'col_3': 'pear', 'col_4':
+        'banana', 'col_5': 'my favorite fruits'}, {'col_1': 'carrot',
+        'col_2': 'squash', 'col_3': 'celery', 'col_4': 'spinach', 'col_5':
+        'my favorite veggies'}, {'col_1': 'chicken', 'col_2': 'beef',
+        'col_3': 'pork', 'col_4': 'eggs', 'col_5': 'my favorite proteins'}]
 
     Parameters:
 
-        data:   (list)   Text data to parse that has been split into lines
+        data:   (iter)   Text data to parse that has been split into lines
                          via .splitlines(). Item 0 must be the header row.
                          Any spaces in header names should be changed to
                          underscore '_'. You should also ensure headers are
@@ -26,6 +37,10 @@ def simple_table_parse(data: List[str]) -> List[Dict]:
     """
     # code adapted from Conor Heine at:
     # https://gist.github.com/cahna/43a1a3ff4d075bcd71f9d7120037a501
+
+    # cast iterable to a list. Also keeps from mutating the caller's list
+    data = list(data)
+
     headers = [h for h in ' '.join(data[0].strip().split()).split() if h]
     raw_data = map(lambda s: s.strip().split(None, len(headers) - 1), data[1:])
     raw_output = [dict(zip(headers, r)) for r in raw_data]
@@ -33,22 +48,36 @@ def simple_table_parse(data: List[str]) -> List[Dict]:
     return raw_output
 
 
-def sparse_table_parse(data: List[str], delim: str = '\u2063') -> List[Dict]:
+def sparse_table_parse(data: Iterable[str], delim: str = '\u2063') -> List[Dict]:
     """
     Parse tables with missing column data or with spaces in column data.
+    Blank cells are converted to None in the resulting dictionary. Data
+    elements must line up within column boundaries.
+
+    Example Table:
+
+        col_1        col_2     col_3     col_4         col_5
+        apple        orange              fuzzy peach   my favorite fruits
+        green beans            celery    spinach       my favorite veggies
+        chicken      beef                brown eggs    my favorite proteins
+
+        [{'col_1': 'apple', 'col_2': 'orange', 'col_3': None, 'col_4':
+        'fuzzy peach', 'col_5': 'my favorite fruits'}, {'col_1':
+        'green beans', 'col_2': None, 'col_3': 'celery', 'col_4': 'spinach',
+        'col_5': 'my favorite veggies'}, {'col_1': 'chicken', 'col_2':
+        'beef', 'col_3': None, 'col_4': 'brown eggs', 'col_5':
+        'my favorite proteins'}]
 
     Parameters:
 
-        data:   (list)   Text data to parse that has been split into lines
-                         via .splitlines(). Item 0 must be the header row.
-                         Any spaces in header names should be changed to
-                         underscore '_'. You should also ensure headers are
-                         lowercase by using .lower(). Do not change the
-                         position of header names as the positions are used
-                         to find the data.
+        data:   (iter)   An iterable of string lines (e.g. str.splitlines())
+                         Item 0 must be the header row. Any spaces in header
+                         names should be changed to underscore '_'. You
+                         should also ensure headers are lowercase by using
+                         .lower(). Do not change the position of header
+                         names as the positions are used to find the data.
 
-                         Also, ensure there are no blank lines (list items)
-                         in the data.
+                         Also, ensure there are no blank line items.
 
         delim:  (string) Delimiter to use. By default `u\\2063`
                          (invisible separator) is used since it is unlikely
@@ -60,6 +89,19 @@ def sparse_table_parse(data: List[str], delim: str = '\u2063') -> List[Dict]:
 
         List of Dictionaries
     """
+    # cast iterable to a list. Also keeps from mutating the caller's list
+    data = list(data)
+
+    # find the longest line and pad all lines with spaces to match
+    max_len = max([len(x) for x in data])
+
+    new_data = []
+    for line in data:
+        new_data.append(line + ' ' * (max_len - len(line)))
+
+    data = new_data
+
+    # find header
     output: List = []
     header_text: str = data.pop(0)
     header_text = header_text + ' '
@@ -92,7 +134,7 @@ def sparse_table_parse(data: List[str], delim: str = '\u2063') -> List[Dict]:
                         h_end = h_spec['end']
                         # check if the location contains whitespace. if not
                         # then move to the left until a space is found
-                        while h_end > 0 and entry[h_end] not in string.whitespace:
+                        while h_end > 0 and not entry[h_end].isspace():
                             h_end -= 1
 
                         # insert custom delimiter
