@@ -13,11 +13,6 @@ Usage (module):
     import jc
     result = jc.parse('wc', wc_command_output)
 
-    or
-
-    import jc.parsers.wc
-    result = jc.parsers.wc.parse(wc_command_output)
-
 Schema:
 
     [
